# HAT reaction plugin

## Introduction

Plugin for KIMMDY to perform hydrogen atom transfer reactions. Loads a trained tensorflow model to predict energy barriers.

## Installation

* Download
* `pip install -e ./`  or for development: `pip install -r requirements.txt`
* Lint with black







